@@ -4,6 +4,7 @@
 # See top-level LICENSE file for more information
 
 from swh.model import hashutil
+from swh.model.identifiers import CoreSWHID
 from swh.objstorage.factory import get_objstorage
 from swh.objstorage.objstorage import compute_hash
 
@@ -11,37 +12,36 @@ from swh.objstorage.objstorage import compute_hash
 class VaultCache:
     """The Vault cache is an object storage that stores Vault bundles.
 
-    This implementation computes sha1('<bundle_type>:<object_id>') as the
+    This implementation computes sha1('<bundle_type>:<swhid>') as the
     internal identifiers used in the underlying objstorage.
     """
 
     def __init__(self, **objstorage):
         self.objstorage = get_objstorage(**objstorage)
 
-    def add(self, obj_type, obj_id, content):
-        sid = self._get_internal_id(obj_type, obj_id)
+    def add(self, bundle_type, swhid: CoreSWHID, content):
+        sid = self._get_internal_id(bundle_type, swhid)
         return self.objstorage.add(content, sid)
 
-    def get(self, obj_type, obj_id):
-        sid = self._get_internal_id(obj_type, obj_id)
+    def get(self, bundle_type, swhid: CoreSWHID):
+        sid = self._get_internal_id(bundle_type, swhid)
         return self.objstorage.get(hashutil.hash_to_bytes(sid))
 
-    def delete(self, obj_type, obj_id):
-        sid = self._get_internal_id(obj_type, obj_id)
+    def delete(self, bundle_type, swhid: CoreSWHID):
+        sid = self._get_internal_id(bundle_type, swhid)
         return self.objstorage.delete(hashutil.hash_to_bytes(sid))
 
-    def add_stream(self, obj_type, obj_id, content_iter):
-        sid = self._get_internal_id(obj_type, obj_id)
+    def add_stream(self, bundle_type, swhid: CoreSWHID, content_iter):
+        sid = self._get_internal_id(bundle_type, swhid)
         return self.objstorage.add_stream(content_iter, sid)
 
-    def get_stream(self, obj_type, obj_id):
-        sid = self._get_internal_id(obj_type, obj_id)
+    def get_stream(self, bundle_type, swhid: CoreSWHID):
+        sid = self._get_internal_id(bundle_type, swhid)
         return self.objstorage.get_stream(hashutil.hash_to_bytes(sid))
 
-    def is_cached(self, obj_type, obj_id):
-        sid = self._get_internal_id(obj_type, obj_id)
+    def is_cached(self, bundle_type, swhid: CoreSWHID):
+        sid = self._get_internal_id(bundle_type, swhid)
         return hashutil.hash_to_bytes(sid) in self.objstorage
 
-    def _get_internal_id(self, obj_type, obj_id):
-        obj_id = hashutil.hash_to_hex(obj_id)
-        return compute_hash("{}:{}".format(obj_type, obj_id).encode())
+    def _get_internal_id(self, bundle_type, swhid: CoreSWHID):
+        return compute_hash("{}:{}".format(bundle_type, swhid).encode())
